C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C****************************
C**     LDM_GET_DSTOR      **
C****************************
C
C
CD-Doc:
C DISTortion_type  SUBROUTINE LDM_GET_DSTOR (VALSTR, IVAL, IFLAG)
CD-end
      SUBROUTINE LDM_GET_DSTOR (VALSTR, IVAL, IFLAG)
C
      INCLUDE 'implicit_none.finc'
C
C Purpose: Get value of string/code parameter DISTOR
C
C Author:  John W. Campbell, June 1993
C
C Arguments:
C
      CHARACTER*(*) VALSTR
      INTEGER IVAL
      INTEGER IFLAG

C  VALSTR    (W)   Value for the parameter as a string 'standard', 'r/toff'
C                  or 'spdxy' (8 chars)
C  IVAL      (W)   Code number 1=standard, 2=r/toff, 3=spdxy
C  IFLAG     (W)   Flag = -1 undefined value
C                       =  0 default value
C                       =  1 value set explicitly
C                       =  2 value set globally
C
C====== GLOBALS:
C
      INCLUDE 'ldm_data.finc'
      EXTERNAL LDM_BDAT
C
C====== LOCALS:
C
      CHARACTER*8 STR(3)

      DATA STR/'standard','r/toff','spdxy'/
C
C-------------------------------------------------------------------------------
C
      IVAL = DSTOR
      VALSTR = STR(IVAL)
      IFLAG = IS_DSTOR
      RETURN
      END
